`Arduinozore`
=============

.. image:: https://travis-ci.org/S-Amiral/arduinozore.svg?branch=master
    :target: https://travis-ci.org/S-Amiral/arduinozore
    :alt: Build status

.. image:: https://img.shields.io/badge/License-MIT-yellow.svg
    :target: http://doge.mit-license.org
    :alt: MIT License

.. image:: https://img.shields.io/pypi/v/Arduinozore.svg?maxAge=2592000
    :target: https://pypi.org/project/Arduinozore/
    :alt: PyPI - Python Version

.. image:: https://img.shields.io/pypi/pyversions/Arduinozore.svg
    :target: https://pypi.org/project/Arduinozore/
    :alt: PyPI - Python Version


Realization of a web interface allowing to visualize sensors data sent by an arduino on a serial port.

This package can be installed via :code:`pip install arduinozore`.

We are still working on this README.
------------------------------------
